@@ -113,7 +113,7 @@ class ANA():
             data_list.append(df)
             file_list.append(self.files[i])
         file_list = np.array([f.split('\\') for f in file_list])
-        spot_num = [int(f[:-3].split('_')[2]) + 1 for f in file_list[:, 1]]
+        spot_num = [int(f[:-3].split('_')[-1]) + 1 for f in file_list[:, 1]]
 
         self.data = pd.DataFrame(data={'Experiment': file_list[:, 0],
                                        'Files': file_list[:, 1],
